@@ -88,7 +88,7 @@ class Club(GloballyUnique, Base):
         info=dict(label=N_('Pairings'),
                   hint=N_('Default method used to pair competitors at each round.'),
                   dictionary=dict(serial=N_('Ranking order'),
-                                  dazed=N_('Dazed ranking order'))))
+                                  dazed=N_('Cross ranking order'))))
     """Kind of pairing method used to build next round, used as default value
     for the corresponding field when creating a new championship."""
 
