@@ -693,7 +693,7 @@ class Player(GloballyUnique, Base):
         return ctors
 
     def matchesSummary(self):
-        "Return the number of won, lost and tied matches."
+        "Return the number of won, lost, tied and single matches."
 
         from . import Competitor, Match
 
@@ -701,26 +701,34 @@ class Player(GloballyUnique, Base):
 
         ct1 = Competitor.__table__.alias()
         ct2 = Competitor.__table__.alias()
-        mt1 = Match.__table__.alias()
-        mt2 = Match.__table__.alias()
+        mt = Match.__table__.alias()
 
         wins = 0
         losts = 0
         ties = 0
+        singles = 0
 
         qm = union_all(
-            select([mt1.c.score1, mt1.c.score2],
+            select([mt.c.score1, mt.c.score2,
+                    ct1.c.idplayer2, ct1.c.idplayer3, ct1.c.idplayer4,
+                    ct2.c.idplayer2, ct2.c.idplayer3, ct2.c.idplayer4],
                    or_(ct1.c.idplayer1 == self.idplayer,
                        ct1.c.idplayer2 == self.idplayer,
                        ct1.c.idplayer3 == self.idplayer,
                        ct1.c.idplayer4 == self.idplayer),
-                   from_obj=mt1.join(ct1, mt1.c.idcompetitor1==ct1.c.idcompetitor)),
-            select([mt2.c.score2, mt2.c.score1],
+                   from_obj=mt
+                   .join(ct1, mt.c.idcompetitor1==ct1.c.idcompetitor)
+                   .join(ct2, mt.c.idcompetitor2==ct2.c.idcompetitor)),
+            select([mt.c.score2, mt.c.score1,
+                    ct1.c.idplayer2, ct1.c.idplayer3, ct1.c.idplayer4,
+                    ct2.c.idplayer2, ct2.c.idplayer3, ct2.c.idplayer4],
                    or_(ct2.c.idplayer1 == self.idplayer,
                        ct2.c.idplayer2 == self.idplayer,
                        ct2.c.idplayer3 == self.idplayer,
                        ct2.c.idplayer4 == self.idplayer),
-                   from_obj=mt2.join(ct2, mt2.c.idcompetitor2==ct2.c.idcompetitor)))
+                   from_obj=mt
+                   .join(ct1, mt.c.idcompetitor1==ct1.c.idcompetitor)
+                   .join(ct2, mt.c.idcompetitor2==ct2.c.idcompetitor)))
 
         for m in s.execute(qm):
             if m[0] > m[1]:
@@ -729,10 +737,13 @@ class Player(GloballyUnique, Base):
                 ties += 1
             else:
                 losts += 1
-        return (wins, losts, ties)
+            if m[2] is m[3] is m[4] is m[5] is m[6] is m[7] is None:
+                singles += 1
+
+        return (wins, losts, ties, singles)
 
     def opponents(self):
-        "Return a summary of the opponents this player met."
+        "Return a summary of the opponents this player met, in singles."
 
         from . import Competitor, Match
 
@@ -740,24 +751,23 @@ class Player(GloballyUnique, Base):
 
         ct1 = Competitor.__table__.alias()
         ct2 = Competitor.__table__.alias()
-        cto1 = Competitor.__table__.alias()
-        cto2 = Competitor.__table__.alias()
-        mt1 = Match.__table__.alias()
-        mt2 = Match.__table__.alias()
+        mt = Match.__table__.alias()
 
         qm = union_all(
-            select([cto1.c.idplayer1, mt1.c.score1, mt1.c.score2],
+            select([ct2.c.idplayer1, mt.c.score1, mt.c.score2],
                    and_(ct1.c.idplayer1 == self.idplayer,
-                        ct1.c.idplayer2 == None),
-                   from_obj=mt1
-                   .join(ct1, mt1.c.idcompetitor1==ct1.c.idcompetitor)
-                   .join(cto1, mt1.c.idcompetitor2==cto1.c.idcompetitor)),
-            select([cto2.c.idplayer1, mt2.c.score2, mt2.c.score1],
-                   and_(ct2.c.idplayer1 == self.idplayer,
+                        ct1.c.idplayer2 == None,
                         ct2.c.idplayer2 == None),
-                   from_obj=mt2
-                   .join(ct2, mt2.c.idcompetitor2==ct2.c.idcompetitor)
-                   .join(cto2, mt2.c.idcompetitor1==cto2.c.idcompetitor)))
+                   from_obj=mt
+                   .join(ct1, mt.c.idcompetitor1==ct1.c.idcompetitor)
+                   .join(ct2, mt.c.idcompetitor2==ct2.c.idcompetitor)),
+            select([ct1.c.idplayer1, mt.c.score2, mt.c.score1],
+                   and_(ct2.c.idplayer1 == self.idplayer,
+                        ct1.c.idplayer2 == None,
+                        ct2.c.idplayer2 == None),
+                   from_obj=mt
+                   .join(ct1, mt.c.idcompetitor1==ct1.c.idcompetitor)
+                   .join(ct2, mt.c.idcompetitor2==ct2.c.idcompetitor)))
 
         summary = {}
 
