@@ -659,8 +659,7 @@ Ext.define('SoL.module.Players', {
     shouldDisableDeleteAction: function() {
         var grid = this;
         var sm = grid.getSelectionModel();
-        var app = grid.up().up().app.desktop.app;
-        var currentuser = app.user;
+        var currentuser = grid.up().up().app.user;
 
         if(sm.getCount() > 0) {
             var selrecs = sm.getSelection();
@@ -748,6 +747,17 @@ Ext.define('SoL.module.Players.MergeTarget', {
         if(!node) {
             return false;
         }
+
+        var app = me.view.up().up().up().app;
+        var currentuser = app.user;
+        if(!currentuser.is_admin) {
+            for(var i=data.records.length-1; i>=0; i--) {
+                if(currentuser.user_id != data.records[i].get('idowner')) {
+                    return false;
+                }
+            }
+        }
+
         var trec = me.view.getRecord(node);
         var tid = trec.get('idplayer');
         var sids = [];
