@@ -168,15 +168,17 @@ Ext.define('SoL.module.Tourney', {
 
             mgrid.store.on({
                 load: function(s, recs, opts) {
-                    var ordinalp = SoL.view.Matches.ordinalp;
-                    if(Ext.isEmpty(recs)) {
-                        mgrid.setTitle(Ext.String.format(_('Matches')));
-                    } else if(recs[0].get('final')) {
-                        mgrid.setTitle(Ext.String.format(_('Matches {0} final round'),
-                                                         ordinalp(recs[0].get('turn'))));
-                    } else {
-                        mgrid.setTitle(Ext.String.format(_('Matches {0} round'),
-                                                         ordinalp(recs[0].get('turn'))));
+                    if(!mgrid.focusedCompetitor) {
+                        var ordinalp = SoL.view.Matches.ordinalp;
+                        if(Ext.isEmpty(recs)) {
+                            mgrid.setTitle(Ext.String.format(_('Matches')));
+                        } else if(recs[0].get('final')) {
+                            mgrid.setTitle(Ext.String.format(_('Matches {0} final round'),
+                                                             ordinalp(recs[0].get('turn'))));
+                        } else {
+                            mgrid.setTitle(Ext.String.format(_('Matches {0} round'),
+                                                             ordinalp(recs[0].get('turn'))));
+                        }
                     }
                 }
             });
